@@ -17,7 +17,7 @@ use HTML5::DOM::Collection;
 use HTML5::DOM::CSS;
 use HTML5::DOM::TokenList;
 
-our $VERSION = '1.08';
+our $VERSION = '1.09';
 require XSLoader;
 
 # https://developer.mozilla.org/pl/docs/Web/API/Element/nodeType
@@ -308,6 +308,40 @@ use constant {
 };
 # </MyHTML_ns>
 
+sub parseAsync($$;$$) {
+	my ($self, $html, $options, $callback) = @_;
+	
+	if (ref($options) eq 'CODE' && !defined $callback) {
+		$callback = $options;
+		$options = {};
+	}
+	
+	if (ref($callback) eq 'CODE') {
+		require EV;
+		require AnyEvent::Util;
+		
+		my ($r, $w) = AnyEvent::Util::portable_pipe();
+		AnyEvent::fh_unblock($r);
+		
+		my $async_w;
+		my $async = $self->_parseAsync($html, $options, fileno($w));
+		
+		$async_w = EV::io($r, EV::READ(), sub {
+			close $w;
+			close $r;
+			undef $w;
+			undef $r;
+			undef $async_w;
+			
+			$callback->($async->wait);
+		});
+		
+		return $async;
+	} else {
+		_parseAsync(@_);
+	}
+}
+
 XSLoader::load('HTML5::DOM', $VERSION);
 
 1;
